@@ -1357,6 +1357,11 @@ class StageBase(TargetBase, ClearBase, GenBase):
             chroot_location = self.to_chroot(location)
             clear_path(str(chroot_location))
 
+        # Ensure that the repo dir and all its contents are owned by portage
+        if os.path.exists(self.settings['stage_path']+self.settings['repo_basedir']):
+            cmd(['chown', '-R', 'portage:portage',
+                self.settings['stage_path']+self.settings['repo_basedir']])
+
         if "sticky-config" not in self.settings["options"]:
             # re-write the make.conf to be sure it is clean
             self.write_make_conf(setup=False)
